@@ -76,13 +76,13 @@ pub fn gl_to_attribute(input: TokenStream) -> TokenStream {
                 type Error = Error #ty_generics;
                 fn to_attribute(
                     self,
-                    context: &::web_sys::WebGl2RenderingContext,
+                    gl : Rc<::rust_gl::GL>,
                     program: &::web_sys::WebGlProgram,
                     name: &str,
                     map : &mut ::std::collections::HashMap<String, ::web_sys::WebGlActiveInfo>,
                 ) -> Result<Self::Output, Self::Error>{
                     let output = Self::Output{#(
-                        #names : self.#names.to_attribute(context, program, #strings, map).map_err(Error::#cased)?,
+                        #names : self.#names.to_attribute(gl.clone(), program, #strings, map).map_err(Error::#cased)?,
                     )*};
                     Ok(output)
                 }
