@@ -76,7 +76,7 @@ pub fn gl_to_uniform(input: TokenStream) -> TokenStream {
                 type Error = Error #ty_generics;
                 fn to_uniform(
                     self,
-                    context : &::web_sys::WebGl2RenderingContext,
+                    gl : Rc<::rust_gl::GL>,
                     program : &::web_sys::WebGlProgram,
                     member : ::core::option::Option<::std::rc::Rc<::rust_gl::uniform::Member>>,
                     map : &mut ::std::collections::HashMap<String, ::web_sys::WebGlActiveInfo>,
@@ -85,7 +85,7 @@ pub fn gl_to_uniform(input: TokenStream) -> TokenStream {
                     let output = Self::Output{#(
                         #names : {
                             let new = ::rust_gl::uniform::Member::Member(member.clone(), #strings.to_string());
-                            self.#names.to_uniform(context, program, ::core::option::Option::Some(::std::rc::Rc::new(new)), map).map_err(Error::#cased)?
+                            self.#names.to_uniform(gl.clone(), program, ::core::option::Option::Some(::std::rc::Rc::new(new)), map).map_err(Error::#cased)?
                         },
                     )*};
                     Ok(output)
